@@ -1,8 +1,9 @@
 package Term::ANSIColor::Concise;
 
-our $VERSION = "2.00_04";
+our $VERSION = "2.00_05";
 
 use v5.14;
+use warnings;
 use utf8;
 
 use Exporter 'import';
@@ -164,7 +165,7 @@ my $colorspec_re = qr{
 sub ansi_numbers {
     local $_ = shift // '';
     my @numbers;
-    my $toggle = Term::ANSIColor::Concise::ToggleValue->new(value => 10);
+    my $toggle = ToggleValue->new(value => 10);
 
     while (m{\G (?: $colorspec_re | (?<err> .+ ) ) }xig) {
 	if ($+{toggle}) {
@@ -400,7 +401,7 @@ Term::ANSIColor::Concise - Produce ANSI terminal sequence by concise notation
 
 =head1 VERSION
 
-Version 2.00_04
+Version 2.00_05
 
 
 =head1 DESCRIPTION
@@ -635,13 +636,13 @@ These sequences do not start with CSI, and do not take parameters.
 
 =head2 EXAMPLES
 
-    RGB  6x6x6    12bit      24bit            color name
+    8+8  6x6x6    12bit      24bit            names
     ===  =======  =========  =============    ==================
     B    005      #00F       (0,0,255)        <blue>
      /M     /505      /#F0F     /(255,0,255)  /<magenta>
     K/W  000/555  #000/#FFF  #000000/#FFFFFF  <black>/<white>
     R/G  500/050  #F00/#0F0  #FF0000/#00FF00  <red>/<green>
-    W/w  L03/L20  #333/#ccc  #303030/#c6c6c6  <dimgray>/<lightgray>
+    W/w  L03/L20  #333/#ccc  #333333/#cccccc  <gray20>/<gray80>
 
 =head1 COLOR NAMES
 
@@ -744,9 +745,9 @@ sometimes mysteriously disappear when it is the last character in the
 colored region.  If you do not like this behavior, set module variable
 C<$NO_RESET_EL> or C<ANSICOLOR_NO_RESET_EL> environment.
 
-Erase Line sequence C<{EL}> clears the line from cursor position to
+I<Erase Line> sequence C<{EL}> clears the line from cursor position to
 the end of the line, which means filling the area by background color.
-When Erase Line is explicitly found in the start sequence, it is
+When I<Erase Line> is explicitly found in the start sequence, it is
 copied to just before (not after) ending reset sequence, with
 preceding sequence if necessary, to keep the effect of filling line
 even if the text is wrapped to multiple lines.
